/////////////////////////////////////////////////////////////////////////////
// bricks.cpp: application implementation file



#include "stdafx.h"
#include "resource.h"

#include "bricks.h"
#include "dlg.h"

#include <time.h>	// Needed for RAND function
#include <stdio.h>	// Needed for RAND function
#include <stdlib.h>	// Needed for RAND function


// Status Bar Indicators
static UINT BASED_CODE indicators[] =
{
	ID_SEPARATOR,			// status line indicator
	ID_INDICATOR_QUOTE,
	ID_INDICATOR_SPEED,
};


/////////////////////////////////////////////////////////////////////////////

// theApp:
// Just creating this application object runs the whole application.
//
CTheApp NEAR theApp;





/////////////////////////////////////////////////////////////////////////////

// CMainWindow constructor:
// Create the window with the appropriate style, size, menu, etc.
//
CMainWindow::CMainWindow()
{
	// Main Window Style
	DWORD winStyle = WS_VISIBLE|WS_OVERLAPPED|
						WS_CAPTION|WS_SYSMENU|WS_MINIMIZEBOX;

    // Calculate Window Size According to the Client Rectangle
	CRect wndRect;
	CClientDC dc(this);

	wndRect.left = (dc.GetDeviceCaps(HORZRES)-WINDOW_WIDTH)/2;
	wndRect.top = (dc.GetDeviceCaps(VERTRES)-WINDOW_HEIGHT)/2;
	wndRect.right = wndRect.left + WINDOW_WIDTH;
	wndRect.bottom = wndRect.top + WINDOW_HEIGHT;
	::AdjustWindowRect(&wndRect,winStyle,TRUE);

	Create(NULL,
			AfxGetAppName(),
			winStyle,
			wndRect,
			NULL,
			"MainMenu");
			
	// Load Accelerator Table
	LoadAccelTable("MAINACCELERATOR");

	// Load the Game Bitmaps
	if (!m_bitmaps.LoadBitmap(IDB_SORTED_BITMAPS))
	{
		AfxMessageBox("Can't Load Bitmaps.",MB_ICONSTOP);
		PostMessage(WM_CLOSE);
		return;
	}

	// Create Status Bar
	if ((!m_statusBar.Create(this))
		|| (!m_statusBar.SetIndicators(indicators,
		  sizeof(indicators)/sizeof(UINT)))) 
	{
		AfxMessageBox("Can't create the Status Bar",MB_ICONSTOP);
		PostMessage(WM_CLOSE);
		return;
	}
	
	// Adjust Window Rect According to Status Bar Size
	RecalcLayout();
	CRect statusBarRect;
	m_statusBar.GetWindowRect(statusBarRect);
	GetWindowRect(wndRect);

	wndRect.bottom += statusBarRect.Height();
	MoveWindow(wndRect,FALSE);
	
	// Set Status Bar Properties
	m_statusBar.SetPaneInfo(0,ID_SEPARATOR,SBPS_STRETCH,0);	
	m_statusBar.SetPaneInfo(1,ID_INDICATOR_QUOTE,SBPS_NORMAL,wndRect.Width()/4);	
	m_statusBar.SetPaneInfo(2,ID_INDICATOR_SPEED,SBPS_NORMAL,wndRect.Width()/5);	

	LOGFONT fontInfo;
	CFont* pFont = m_statusBar.GetFont();
    pFont->GetObject(sizeof(LOGFONT),&fontInfo);
    
	// Modify Window Font 
    fontInfo.lfHeight = -STATUS_BAR_FONT_HEIGHT;
    _fstrcpy(fontInfo.lfFaceName,STATUS_BAR_FONT_NAME);
    
    pFont->DeleteObject();
    pFont->CreateFontIndirect(&fontInfo);
	
	// Set RAND Seed
	srand((unsigned)time(NULL));

	// Load Strings
	m_quoteStr.LoadString(ID_INDICATOR_QUOTE);
	m_speedStr.LoadString(ID_INDICATOR_SPEED);
	
	// Prepare Game Board                   
	int row,col;
	for (row=0; row<VERT_CELLS; row++)
		for (col=0; col<HORZ_CELLS; col++)
			m_board[col][row] = NOTHING;
			
	// Init Other Variables
	m_started = FALSE;
	m_lastDirection = NODIR;	
}

void CMainWindow::OnDestroy()
{
	CTheApp* pApp = (CTheApp*)AfxGetApp();
	
	// Save Record Table           
	pApp->WriteProfileString(HISCORES_SECTION,LOW_NAME_ENTRY,m_lName);
	pApp->WriteProfileInt(HISCORES_SECTION,LOW_RECORD_ENTRY,(int)(m_lQuote*10));	
	pApp->WriteProfileString(HISCORES_SECTION,MED_NAME_ENTRY,m_mName);
	pApp->WriteProfileInt(HISCORES_SECTION,MED_RECORD_ENTRY,(int)(m_mQuote*10));	
	pApp->WriteProfileString(HISCORES_SECTION,HIGH_NAME_ENTRY,m_hName);   
	pApp->WriteProfileInt(HISCORES_SECTION,HIGH_RECORD_ENTRY,(int)(m_hQuote*10));	

	// Save Current Speed
	pApp->WriteProfileInt(PARAMETERS_SECTION,GAME_SPEED_ENTRY,m_gameSpeed);	
		
	CFrameWnd::OnDestroy();
}

CMainWindow::~CMainWindow()
{
	m_bitmaps.DeleteObject();
}



/////////////////////////////////////////////////////////////////////////////
// CMainWindow message map:
BEGIN_MESSAGE_MAP( CMainWindow, CFrameWnd )
	//{{AFX_MSG_MAP( CMainWindow )
	ON_WM_PAINT()
	ON_WM_KEYDOWN()
	ON_WM_TIMER()
	ON_WM_DESTROY()
	ON_COMMAND(ID_GAME_NEW, OnGameNew)
	ON_COMMAND(ID_GAME_SOUND, OnGameSound)
	ON_UPDATE_COMMAND_UI(ID_GAME_SOUND, OnUpdateGameSound)
	ON_COMMAND(ID_GAME_SPEED_LOW, OnGameSpeedLow)
	ON_UPDATE_COMMAND_UI(ID_GAME_SPEED_LOW, OnUpdateGameSpeedLow)
	ON_COMMAND(ID_GAME_SPEED_HIGH, OnGameSpeedHigh)
	ON_UPDATE_COMMAND_UI(ID_GAME_SPEED_HIGH, OnUpdateGameSpeedHigh)
	ON_COMMAND(ID_GAME_SPEED_MEDIUM, OnGameSpeedMedium)
	ON_UPDATE_COMMAND_UI(ID_GAME_SPEED_MEDIUM, OnUpdateGameSpeedMedium)
	ON_COMMAND(ID_GAME_OPTIONS, OnGameOptions)
	ON_COMMAND(ID_GAME_HISCORES, OnGameHiscores)
	ON_COMMAND(ID_HELP_ABOUT, OnHelpAbout)
	ON_COMMAND(ID_HELP_RULES, OnHelpRules)
	ON_COMMAND(ID_GAME_BITMAPS_BRICKS, OnGameBitmapsBricks)
	ON_UPDATE_COMMAND_UI(ID_GAME_BITMAPS_BRICKS, OnUpdateGameBitmapsBricks)
	ON_COMMAND(ID_GAME_BITMAPS_TILES, OnGameBitmapsTiles)
	ON_UPDATE_COMMAND_UI(ID_GAME_BITMAPS_TILES, OnUpdateGameBitmapsTiles)
	//}}AFX_MSG_MAP
	ON_UPDATE_COMMAND_UI(ID_INDICATOR_QUOTE, UpdateQuotePane)
	ON_UPDATE_COMMAND_UI(ID_INDICATOR_SPEED, UpdateSpeedPane)
END_MESSAGE_MAP()



/////////////////////////////////////////////////////////////////////////////
// Status Bar Pane Enabling

void CMainWindow::UpdateQuotePane(CCmdUI* pCmdUI)
{
	pCmdUI->Enable(TRUE);
}

void CMainWindow::UpdateSpeedPane(CCmdUI* pCmdUI)
{
	pCmdUI->Enable(TRUE);
}



/////////////////////////////////////////////////////////////////////////////
// Game Menu Management

void CMainWindow::OnGameNew()
{
	if (m_started)
		EndGame();
		
	StartGame();
}

void CMainWindow::OnGameSound()
{
	m_sound = !m_sound;
}

void CMainWindow::OnUpdateGameSound(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_sound);	
}

void CMainWindow::OnGameSpeedLow()
{
	m_gameSpeed = m_lowSpeed;
	OnGameNew();
}

void CMainWindow::OnUpdateGameSpeedLow(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_gameSpeed==m_lowSpeed);
}

void CMainWindow::OnGameSpeedMedium()
{
	m_gameSpeed = m_medSpeed;
	OnGameNew();
}

void CMainWindow::OnUpdateGameSpeedMedium(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_gameSpeed==m_medSpeed);
}

void CMainWindow::OnGameSpeedHigh()
{
	m_gameSpeed = m_highSpeed;
	OnGameNew();
}

void CMainWindow::OnUpdateGameSpeedHigh(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_gameSpeed==m_highSpeed);
}

void CMainWindow::OnGameBitmapsBricks()
{
	m_useBricks = TRUE;
	OnGameNew();
}

void CMainWindow::OnUpdateGameBitmapsBricks(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_useBricks);	
}

void CMainWindow::OnGameBitmapsTiles()
{
	m_useBricks = FALSE;
	OnGameNew();
}

void CMainWindow::OnUpdateGameBitmapsTiles(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(!m_useBricks);	
}

void CMainWindow::OnGameOptions()
{
	if (m_started)
		EndGame(FALSE);
		
	COptionsDlg dlg(this);

	dlg.m_clicks = m_sound;
	dlg.m_useBricks = m_useBricks;
	dlg.m_lowSpeed = m_lowSpeed;
	dlg.m_medSpeed = m_medSpeed;
	dlg.m_highSpeed = m_highSpeed;	
	dlg.m_gameSpeed = m_gameSpeed;
	dlg.m_hurdlesFreq = m_hurdlesFreq;
	
	if (dlg.DoModal()==IDOK)
	{
		if ((dlg.m_lowSpeed!=DEF_LOW_SPEED)
			|| (dlg.m_medSpeed!=DEF_MED_SPEED)
			|| (dlg.m_highSpeed!=DEF_HIGH_SPEED)
			|| (dlg.m_hurdlesFreq!=DEF_HURDLES_FREQ))
		{

			CDialog askDlg("NORERECORDSDLG",this);
			if (askDlg.DoModal()==IDOK)
			{
				m_sound = dlg.m_clicks;
				m_useBricks = dlg.m_useBricks;
				m_lowSpeed = dlg.m_lowSpeed;
				m_medSpeed = dlg.m_medSpeed;
				m_highSpeed = dlg.m_highSpeed;	
				m_gameSpeed = dlg.m_gameSpeed;
				m_hurdlesFreq = dlg.m_hurdlesFreq;
			}
		}		
		else
		{
			m_sound = dlg.m_clicks;
			m_useBricks = dlg.m_useBricks;
			m_lowSpeed = dlg.m_lowSpeed;
			m_medSpeed = dlg.m_medSpeed;
			m_highSpeed = dlg.m_highSpeed;	
			m_gameSpeed = dlg.m_gameSpeed;
			m_hurdlesFreq = dlg.m_hurdlesFreq;
		}
	}                               
}

void CMainWindow::OnGameHiscores()
{                
	if (m_started)
		EndGame(FALSE);
		
	CHiScoresDlg dlg(this);
	dlg.m_lName = m_lName;
	dlg.m_mName = m_mName;
	dlg.m_hName = m_hName;
	dlg.m_lQuote = m_lQuote;
	dlg.m_mQuote = m_mQuote;
	dlg.m_hQuote = m_hQuote;

	dlg.DoModal();
}



/////////////////////////////////////////////////////////////////////////////
// Help Menu Management

void CMainWindow::OnHelpAbout()
{
	if (m_started)
		EndGame(FALSE);
		
	CDialog dlg("ABOUTBOX",this);
	dlg.DoModal();
}

void CMainWindow::OnHelpRules()
{
	if (m_started)
		EndGame(FALSE);
		
	CDialog dlg("RULESDLG",this);
	dlg.DoModal();
}



/////////////////////////////////////////////////////////////////////////////
// Keyboard Management

void CMainWindow::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
{
	if (!m_started)                 
	{
		StartGame();
		return;
	}
	
	CClientDC dc(this);
	
	switch(nChar)
	{
		case UP_ARROW		:	if (m_lastDirection!=DOWN)
									m_lastDirection = UP;
								break;
		case LEFT_ARROW		:	if (m_lastDirection!=RIGHT)
									m_lastDirection = LEFT;   
								break;
		case DOWN_ARROW		:	if (m_lastDirection!=UP)
									m_lastDirection = DOWN;   
								break;   
		case RIGHT_ARROW	:	if (m_lastDirection!=LEFT)
									m_lastDirection = RIGHT;   
								break;
		case ESC_KEY		:	EndGame(FALSE);
								ShowWindow(SW_MINIMIZE);
								break;
	}
}



/////////////////////////////////////////////////////////////////////////////
// Painting Management

void CMainWindow::OnPaint()
{
	CPaintDC dc(this); 
	CRect bkArea(0,0,WINDOW_WIDTH,WINDOW_HEIGHT);

	// Select the Background Brush
	CBrush bkBrush;
	bkBrush.CreateSolidBrush(BCKGRND_COLOR);
	
	// Paint the Background
	dc.FillRect(bkArea,&bkBrush);	
	bkBrush.DeleteObject();
	
	// Bitmap Transfer
	CDC memDC;
	memDC.CreateCompatibleDC(&dc);
	CBitmap* pOldBitmap = memDC.SelectObject(&m_bitmaps);

	int bmpIndex;
	for (int row=0; row<VERT_CELLS; row++)
		for (int col=0; col<HORZ_CELLS; col++)
		{
			if (m_board[col][row]!=NOTHING)
			{
				// Calculate Bitmap Index (and Position...)
			  bmpIndex = m_board[col][row];
			  
			  if ((!m_billFirstFrame)
			  	&& (bmpIndex>=MANUP))
			  	bmpIndex += 4;

				bmpIndex--;
				dc.BitBlt(col*CELL_WIDTH,row*CELL_HEIGHT,
						  CELL_WIDTH,CELL_HEIGHT,&memDC,
						  bmpIndex*CELL_WIDTH,0,SRCCOPY);
			}
		}	
	
	// Restore DC Parameters
	memDC.SelectObject(pOldBitmap);
	memDC.DeleteDC();
	
	bkArea.bottom--;
	ValidateRect(bkArea);	
}


/////////////////////////////////////////////////////////////////////////////
// Game Events Management

void CMainWindow::StartGame()
{
	BeginWaitCursor();
	
	// Prepare Game Board                   
	int row,col;
	for (row=0; row<VERT_CELLS; row++)
		for (col=0; col<HORZ_CELLS; col++)
			m_board[col][row] = NOTHING;
			
	// Random Obstacles Placement
	int hurdles = (int)((long)VERT_CELLS*HORZ_CELLS*m_hurdlesFreq/100);
	
	while (hurdles>=0)
	{
		row = (int)(((float)rand()-1)/RAND_MAX*VERT_CELLS);		
		col = (int)(((float)rand()-1)/RAND_MAX*HORZ_CELLS);		
		
		if (m_board[col][row]==NOTHING)
		{
			m_board[col][row] = OBSTACLE;
			hurdles--;		
		}
	}
	
	// Set Man's Random Position
	do {

		m_yCoor = (int)(((float)rand())/RAND_MAX*(VERT_CELLS-1));		
		m_xCoor = (int)(((float)rand())/RAND_MAX*(HORZ_CELLS-1));		
	         
	} while (m_board[m_xCoor][m_yCoor]!=NOTHING);
	
	m_board[m_xCoor][m_yCoor] = MANRIGHT;
	
	m_started = TRUE; 
	m_percDone = 0;
	m_stepsDone = 0; 
	m_lastDirection = NODIR;
	m_billFirstFrame = TRUE;

	if (m_gameSpeed<=0)
		m_gameSpeed = DEF_MED_SPEED;

	char buffer[8];
	m_statusBar.SetPaneText(1,m_quoteStr + "0");
	m_statusBar.SetPaneText(2,m_speedStr + _itoa(m_gameSpeed,buffer,10));
	
	// Repaint Window
	Invalidate(FALSE);
	UpdateWindow();

	EndWaitCursor();

	SetTimer(MOTION_TIMER_ID,MOTION_TIMEOUT,NULL);
	SetTimer(BRICKS_TIMER_ID,1000/m_gameSpeed,NULL);
}

void CMainWindow::OnTimer(UINT nIDEvent)
{
	if (nIDEvent==BRICKS_TIMER_ID)
	{
		CRect paintRect;
		paintRect.left = m_xCoor*CELL_WIDTH;
		paintRect.top = m_yCoor*CELL_HEIGHT;
		paintRect.right = paintRect.left + CELL_WIDTH;
		paintRect.bottom = paintRect.top + CELL_HEIGHT;
		
		// Can Make a Step?
		if (((m_xCoor==0)
				|| ((m_xCoor>0)
					&& (m_board[m_xCoor-1][m_yCoor]!=NOTHING)))
				
			&&			

			((m_yCoor==0)
				|| ((m_yCoor>0)
					&& (m_board[m_xCoor][m_yCoor-1]!=NOTHING)))
				
			&&

			((m_xCoor==HORZ_CELLS-1)
				|| ((m_xCoor<HORZ_CELLS-1)
					&& (m_board[m_xCoor+1][m_yCoor]!=NOTHING)))
				

			&&

			((m_yCoor==VERT_CELLS-1)
				|| ((m_yCoor<VERT_CELLS-1)
					&& (m_board[m_xCoor][m_yCoor+1]!=NOTHING))))
		
		{
			// Game is Ended...
			m_board[m_xCoor][m_yCoor] = DEADMAN;
			InvalidateRect(paintRect,FALSE);
			UpdateWindow();

			EndGame();
			return;
		}
			
		// Make a Step
		BOOL stepDone = FALSE;
		
		if ((m_lastDirection==UP)	      
			&& (m_yCoor>0)
			&& (m_board[m_xCoor][m_yCoor-1]==NOTHING))
		{
			m_board[m_xCoor][m_yCoor] = (m_useBricks) ? BRICKS : TILES;
			m_board[m_xCoor][m_yCoor-1] = MANUP;
			m_yCoor--;
			stepDone = TRUE;

			// Redraw Man's Shape
			paintRect.top -= CELL_HEIGHT;
			InvalidateRect(paintRect,FALSE);
			UpdateWindow();
		}

		if ((m_lastDirection==LEFT)	      
			&& (m_xCoor>0)
			&& (m_board[m_xCoor-1][m_yCoor]==NOTHING))
		{
			m_board[m_xCoor][m_yCoor] =  (m_useBricks) ? BRICKS : TILES;
			m_board[m_xCoor-1][m_yCoor] = MANLEFT;
			m_xCoor--;
			stepDone = TRUE;

			// Redraw Man's Shape
			paintRect.left -= CELL_WIDTH;
			InvalidateRect(paintRect,FALSE);
			UpdateWindow();
		}

		if ((m_lastDirection==DOWN)	      
			&& (m_yCoor<VERT_CELLS-1)
			&& (m_board[m_xCoor][m_yCoor+1]==NOTHING))
		{
			m_board[m_xCoor][m_yCoor] =  (m_useBricks) ? BRICKS : TILES;
			m_board[m_xCoor][m_yCoor+1] = MANDOWN;
			m_yCoor++;
			stepDone = TRUE;

			// Redraw Man's Shape
			paintRect.bottom += CELL_HEIGHT;
			InvalidateRect(paintRect,FALSE);
			UpdateWindow();
		}

		if ((m_lastDirection==RIGHT)	      
			&& (m_xCoor<HORZ_CELLS-1)
			&& (m_board[m_xCoor+1][m_yCoor]==NOTHING))
		{
			m_board[m_xCoor][m_yCoor] =  (m_useBricks) ? BRICKS : TILES;
			m_board[m_xCoor+1][m_yCoor] = MANRIGHT;
			m_xCoor++;
			stepDone = TRUE;

			// Redraw Man's Shape
			paintRect.right += CELL_WIDTH;
			InvalidateRect(paintRect,FALSE);
			UpdateWindow();
		}

		if (stepDone)
		{                 
			if (m_sound)
				MessageBeep(-1);

			m_stepsDone++;
			m_percDone = ((double)m_stepsDone)/(VERT_CELLS*HORZ_CELLS)*100;
		
			char buffer[8];
			sprintf(buffer,"%3.1f%%",m_percDone);
			m_statusBar.SetPaneText(1,m_quoteStr + buffer);
		}                                                
		else
			m_lastDirection = NODIR;
			
		return;
	}

	if (nIDEvent==MOTION_TIMER_ID)
    {	
		// Switch Bitmap Frame
		m_billFirstFrame = !m_billFirstFrame;

		// Draw New Man's Frame
		CRect paintRect;
		paintRect.left = m_xCoor*CELL_WIDTH;
		paintRect.top = m_yCoor*CELL_HEIGHT;
		paintRect.right = paintRect.left + CELL_WIDTH;
		paintRect.bottom = paintRect.top + CELL_HEIGHT;
		
		InvalidateRect(paintRect,FALSE);
		UpdateWindow();
		return;
	}
	
	CFrameWnd::OnTimer(nIDEvent);
}

void CMainWindow::EndGame(BOOL bCheckQuote /*=TRUE*/)
{
	KillTimer(BRICKS_TIMER_ID);
	KillTimer(MOTION_TIMER_ID);
	m_started = FALSE;                              
	
	if (bCheckQuote)
	{
		// New Record?    
		double* prevQuote = NULL;
		CString* prevName = NULL;            
		
		if ((m_gameSpeed==DEF_LOW_SPEED)
			&& (m_hurdlesFreq==DEF_HURDLES_FREQ))
		{
			prevName = &m_lName;
			prevQuote = &m_lQuote;
		}
		
		if ((m_gameSpeed==DEF_MED_SPEED)
			&& (m_hurdlesFreq==DEF_HURDLES_FREQ))
		{
			prevName = &m_mName;
			prevQuote = &m_mQuote;
		}

		if ((m_gameSpeed==DEF_HIGH_SPEED)
			&& (m_hurdlesFreq==DEF_HURDLES_FREQ))
		{
			prevName = &m_hName;
			prevQuote = &m_hQuote;
		}
			
		if ((prevQuote!=NULL)
			&& (*prevQuote<m_percDone))
		{
			CAskNameDlg dlg(this);
			dlg.DoModal();
			
			*prevQuote = m_percDone;
			*prevName = dlg.m_name;
			
			OnGameHiscores();
		}
	}
}

 
 
/////////////////////////////////////////////////////////////////////////////
// CTheApp

// InitInstance:
// When any CTheApp object is created, this member function is automatically
// called.  Any data may be set up at this point.
//
// Also, the main window of the application should be created and shown here.
// Return TRUE if the initialization is successful.
//
BOOL CTheApp::InitInstance()
{
	SetDialogBkColor();     // hook gray dialogs (was default in MFC V1)

    CString appName;
    appName.LoadString(AFX_IDS_APP_TITLE);
	m_pszAppName = appName;	

	m_pMainWnd = new CMainWindow();
    CMainWindow* pWnd = (CMainWindow*)m_pMainWnd;

	// Load Parameters
	pWnd->m_sound = GetProfileInt(PARAMETERS_SECTION,CLICKS_ENTRY,DEF_CLICKS);	
	pWnd->m_useBricks = GetProfileInt(PARAMETERS_SECTION,BRICKS_ENTRY,DEF_BRICKS);	
	pWnd->m_lowSpeed = GetProfileInt(PARAMETERS_SECTION,LOW_SPEED_ENTRY,DEF_LOW_SPEED);	
	pWnd->m_medSpeed = GetProfileInt(PARAMETERS_SECTION,MED_SPEED_ENTRY,DEF_MED_SPEED);	
	pWnd->m_highSpeed = GetProfileInt(PARAMETERS_SECTION,HIGH_SPEED_ENTRY,DEF_HIGH_SPEED);	
	pWnd->m_gameSpeed = GetProfileInt(PARAMETERS_SECTION,GAME_SPEED_ENTRY,DEF_MED_SPEED);	
	pWnd->m_hurdlesFreq = GetProfileInt(PARAMETERS_SECTION,HURDLES_ENTRY,DEF_HURDLES_FREQ);	

	// Load Record Table
	pWnd->m_lName = GetProfileString(HISCORES_SECTION,LOW_NAME_ENTRY,DEF_LOW_NAME);
	pWnd->m_lQuote = ((double)GetProfileInt(HISCORES_SECTION,LOW_RECORD_ENTRY,DEF_LOW_QUOTE))/10;	
	pWnd->m_mName = GetProfileString(HISCORES_SECTION,MED_NAME_ENTRY,DEF_MED_NAME);
	pWnd->m_mQuote = ((double)GetProfileInt(HISCORES_SECTION,MED_RECORD_ENTRY,DEF_MED_QUOTE))/10;	
	pWnd->m_hName = GetProfileString(HISCORES_SECTION,HIGH_NAME_ENTRY,DEF_HIGH_NAME);
	pWnd->m_hQuote = ((double)GetProfileInt(HISCORES_SECTION,HIGH_RECORD_ENTRY,DEF_HIGH_QUOTE))/10;	

	m_pMainWnd->ShowWindow(m_nCmdShow);
	m_pMainWnd->RedrawWindow(NULL,NULL,RDW_INVALIDATE|RDW_ERASE|RDW_FRAME|RDW_UPDATENOW);

	return TRUE;
}




