/////////////////////////////////////////////////////////////////////////////
// bricks.h: application definition file

#ifndef __BRICKS_H__
#define __BRICKS_H__


#include "afxext.h"		// CStatusBar Declaration


// Game Defaults
#define DEF_CLICKS				0
#define DEF_BRICKS				1
#define BRICKS_TIMER_ID			0x01      
#define MOTION_TIMER_ID			0x02
#define MOTION_TIMEOUT			300
#define STATUS_BAR_FONT_HEIGHT	8	
#define STATUS_BAR_FONT_NAME	"MS Sans Serif"


// Game Speeds (Steps per Sec)
#define MIN_SPEED		5
#define MAX_SPEED		50
#define DEF_LOW_SPEED	10
#define DEF_MED_SPEED	30
#define DEF_HIGH_SPEED	50


// Game Parameters
#define MIN_HURDLES_FREQ	0
#define MAX_HURDLES_FREQ	80
#define DEF_HURDLES_FREQ	15

// Game Area Macros (measured in pixels)
#define CELL_WIDTH		24
#define CELL_HEIGHT		24
#define HORZ_CELLS		12
#define VERT_CELLS		10
#define WINDOW_WIDTH	(CELL_WIDTH*HORZ_CELLS)
#define WINDOW_HEIGHT	(CELL_HEIGHT*VERT_CELLS + 1)


// Color Macros
#define BLACK			RGB(0x00,0x00,0x00)
#define WHITE			RGB(0xff,0xff,0xff)
#define DARKGREY		RGB(0x80,0x80,0x80)
#define GREY			RGB(0xc0,0xc0,0xc0)
#define BROWN			RGB(0x80,0x00,0x00)
#define RED				RGB(0xff,0x00,0x00)
#define YELLOW			RGB(0x80,0x80,0x00)
#define LIGHTYELLOW		RGB(0xff,0xff,0x00)
#define GREEN			RGB(0x00,0x80,0x00)
#define LIGHTGREEN		RGB(0x00,0xff,0x00)
#define CYAN			RGB(0x00,0x80,0x80)
#define LIGHTCYAN		RGB(0x00,0xff,0xff)
#define BLUE			RGB(0x00,0x00,0x80)
#define LIGHTBLUE		RGB(0x00,0x00,0xff)
#define MAGENTA			RGB(0x80,0x00,0x80)
#define FUCSIA			RGB(0xff,0x00,0xff)

#define BCKGRND_COLOR	GREEN 


// KeyBoard Macros
#define	LEFT_ARROW		0x25
#define UP_ARROW		0x26
#define	RIGHT_ARROW		0x27
#define DOWN_ARROW		0x28
#define ESC_KEY			0x1b


// .INI Sections & Entries	        
#define	PARAMETERS_SECTION		"Game Parameters"
#define CLICKS_ENTRY			"Step Click"
#define BRICKS_ENTRY			"Use Bricks"
#define LOW_SPEED_ENTRY			"Low Speed"
#define MED_SPEED_ENTRY			"Medium Speed"
#define HIGH_SPEED_ENTRY		"High Speed"
#define GAME_SPEED_ENTRY		"Game Speed"
#define HURDLES_ENTRY			"Obstacle Frequency"

#define HISCORES_SECTION		"Record"
#define LOW_NAME_ENTRY			"LName"
#define LOW_RECORD_ENTRY		"LQuote"
#define MED_NAME_ENTRY			"MName"
#define MED_RECORD_ENTRY		"MQuote"
#define HIGH_NAME_ENTRY			"HName"
#define HIGH_RECORD_ENTRY		"HQuote"
	               

// Default Record Table
#define DEF_LOW_NAME			"Unknown"
#define DEF_LOW_QUOTE			0
#define DEF_MED_NAME			"Unknown"
#define DEF_MED_QUOTE			0
#define DEF_HIGH_NAME			"Unknown"         
#define DEF_HIGH_QUOTE			0
	                                

/////////////////////////////////////////////////////////////////////////////

// CMainWindow:
class CMainWindow : public CFrameWnd
{
protected:
	// Data Types
	enum DIRS	{	NODIR = 0,
					UP,
					LEFT,
					DOWN,
					RIGHT };
	
	// DO NOT CHANGE ORDERING!!
	enum ITEMS	{	NOTHING = 0,
					TILES,
					BRICKS,
					OBSTACLE,
					DEADMAN,
					MANUP,
					MANLEFT,
					MANDOWN,
					MANRIGHT };

public:
	CMainWindow();
	~CMainWindow();

	// Status Bar
	CString		m_quoteStr;
	CString		m_speedStr;
	CStatusBar	m_statusBar;
	
	// Bitmaps
	CBitmap	m_bitmaps;             
	BOOL	m_billFirstFrame;
	
	// Game Board
	int		m_xCoor;
	int		m_yCoor;      
	BOOL	m_started;
	double	m_percDone;
	int		m_stepsDone;  
	int		m_hurdlesFreq;
	DIRS	m_lastDirection;
	ITEMS	m_board[HORZ_CELLS][VERT_CELLS];    
	
	// Game Parameters	     
	BOOL	m_sound;              
	BOOL	m_useBricks;              
	int		m_lowSpeed;
	int		m_medSpeed;
	int		m_highSpeed;
	int		m_gameSpeed;
	
	// Record Table
	CString	m_lName;
	CString	m_mName;
	CString	m_hName;
	double	m_lQuote;
	double	m_mQuote;
	double	m_hQuote;
	

	//{{AFX_MSG(CMainWindow)
	afx_msg void OnPaint();
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnDestroy();
	afx_msg void OnGameNew();
	afx_msg void OnGameSound();
	afx_msg void OnUpdateGameSound(CCmdUI* pCmdUI);
	afx_msg void OnGameSpeedLow();
	afx_msg void OnUpdateGameSpeedLow(CCmdUI* pCmdUI);
	afx_msg void OnGameSpeedHigh();
	afx_msg void OnUpdateGameSpeedHigh(CCmdUI* pCmdUI);
	afx_msg void OnGameSpeedMedium();
	afx_msg void OnUpdateGameSpeedMedium(CCmdUI* pCmdUI);
	afx_msg void OnGameOptions();
	afx_msg void OnGameHiscores();
	afx_msg void OnHelpAbout();
	afx_msg void OnHelpRules();
	afx_msg void OnGameBitmapsBricks();
	afx_msg void OnUpdateGameBitmapsBricks(CCmdUI* pCmdUI);
	afx_msg void OnGameBitmapsTiles();
	afx_msg void OnUpdateGameBitmapsTiles(CCmdUI* pCmdUI);
	//}}AFX_MSG

	// Status Bar Panes Enabling
	afx_msg void UpdateQuotePane(CCmdUI* pCmdUI);
	afx_msg void UpdateSpeedPane(CCmdUI* pCmdUI);

	DECLARE_MESSAGE_MAP()                          
	
	void StartGame();
	void EndGame(BOOL bCheckQuote = TRUE);
};

/////////////////////////////////////////////////////////////////////////////

// CTheApp:
// See hello.cpp for the code to the InitInstance member function.
//
class CTheApp : public CWinApp
{
public:
	BOOL InitInstance();
};

/////////////////////////////////////////////////////////////////////////////

#endif // __BRICKS_H__

